@@ -1,6 +1,6 @@
 /*
  * SARG Squid Analysis Report Generator      http://sarg.sourceforge.net
- *                                                            1998, 2012
+ *                                                            1998, 2013
  *
  * SARG donations:
  *      please look at http://sarg.sourceforge.net/donations.php
@@ -535,7 +535,7 @@ void htmlrel(void)
 					}
 					while(fgets(tmp6,sizeof(tmp6),fp_usr)!=NULL) {
 						fixendofline(tmp6);
-						if(strcmp(tmp6,uinfo->label) == 0) {
+						if(strcmp(tmp6,uinfo->ip) == 0) {
 							limit_flag=1;
 							break;
 						}
@@ -548,7 +548,7 @@ void htmlrel(void)
 						debuga(_("(html10) Cannot open file %s\n"),PerUserLimitFile);
 						exit(EXIT_FAILURE);
 					}
-					fprintf(fp_usr,"%s\n",uinfo->label);
+					fprintf(fp_usr,"%s\n",uinfo->ip);
 					fclose(fp_usr);
 
 					if(debug)
