@@ -43,6 +43,8 @@ struct userinfostruct
 {
 	//! The ID of the user as found in the input file.
 	char id[MAX_USER_LEN];
+	//! The user's IP address.
+	char ip[30];
 	//! \c True if the ID is in fact the IP address from which the user connected.
 	bool id_is_ip;
 	//! \c True if the user doesn't have a report file.
@@ -224,7 +226,7 @@ void usage(const char *prog);
 void useragent(void);
 
 // userinfo.c
-/*@shared@*/struct userinfostruct *userinfo_create(const char *userid);
+/*@shared@*/struct userinfostruct *userinfo_create(const char *userid,const char *ip);
 void userinfo_free(void);
 /*@shared@*/struct userinfostruct *userinfo_find_from_file(const char *filename);
 /*@shared@*/struct userinfostruct *userinfo_find_from_id(const char *id);
