@@ -1,6 +1,6 @@
 /*
  * SARG Squid Analysis Report Generator      http://sarg.sourceforge.net
- *                                                            1998, 2012
+ *                                                            1998, 2013
  *
  * SARG donations:
  *      please look at http://sarg.sourceforge.net/donations.php
@@ -1461,7 +1461,7 @@ int main(int argc,char *argv[])
 				memset(ufile,0,sizeof(*ufile));
 				ufile->next=first_user_file;
 				first_user_file=ufile;
-				uinfo=userinfo_create(user);
+				uinfo=userinfo_create(user,ip);
 				ufile->user=uinfo;
 				uinfo->id_is_ip=id_is_ip;
 				nusers++;
